// Copyright (c) 2012 by István Váradi

// This file is part of libxplcommon, a common utility library for
// development related to X-Plane

// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:

// 1. Redistributions of source code must retain the above copyright notice, this
//    list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright notice,
//    this list of conditions and the following disclaimer in the documentation
//    and/or other materials provided with the distribution.

// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// The views and conclusions contained in the software and documentation are those
// of the authors and should not be interpreted as representing official policies,
// either expressed or implied, of the FreeBSD Project.

#ifndef XPLCOMMON_ACCEPTOR_H
#define XPLCOMMON_ACCEPTOR_H
//------------------------------------------------------------------------------

#include "Failable.h"

//------------------------------------------------------------------------------

#if 0 // The public interface of a connection acceptor for a socket

//------------------------------------------------------------------------------

namespace xplcommon {

//------------------------------------------------------------------------------

/**
 * Class representing the accepting of an incoming connection on a
 * socket. It cannot be created directly, only acquired from a server
 * socket. Usually some more concrete subclass is returned from which
 * the socket representing the accepted connection can be queried.
 */
class Acceptor : public FailableReference<Acceptor>
{
public:
    /**
     * Destroy the acceptor.
     */
    virtual ~Acceptor();

    /**
     * Start accepting a connection.
     *
     * If a connection is already accepted, but not retrieved yet, it
     * returns true.
     *
     * If a new socket becomes immediately available, it returns true.
     *
     * If some error occurs, the acceptor is marked as failed.
     */
    bool accept();
};

//------------------------------------------------------------------------------

} /* namespace xplcommon */

//------------------------------------------------------------------------------

#endif // 0, The public interface of a connection acceptor for a socket

//------------------------------------------------------------------------------

#include "config.h"

//------------------------------------------------------------------------------

#if TARGET_API_WIN32

//------------------------------------------------------------------------------

#include "win32/Acceptor.h"

namespace xplcommon { typedef win32::Acceptor Acceptor; }

//------------------------------------------------------------------------------

#else // TARGET_API_WIN32

//------------------------------------------------------------------------------

#include "posix/Acceptor.h"

namespace xplcommon { typedef posix::Acceptor Acceptor; }

//------------------------------------------------------------------------------

#endif // TARGET_API_WIN32

//------------------------------------------------------------------------------
#endif // XPLCOMMON_ACCEPTOR_H

// Local Variables:
// mode: C++
// c-basic-offset: 4
// indent-tabs-mode: nil
// End:
